/**
 * 帮助中心api
 */
import http from "@/api/http.js"

export const assistanceDocInterence = {
    /**
     * 获取文章列表
     * @param Keyword String 文章标题
     * @param PageSize number 每页数据条数
     * @param CurrentIndex number 当前页面
     * @param ClassifyId number 分类id
     * @returns 
     */
    getAssistanceDocList:(params)=>{
      return http.get('/help_doc/list',params)
    },
    /**
     * 新增文章
     * @param ClassifyId number 分类Id
     * @param Title string 题目
     * @param Author string 作者
     * @param Status number 1
     * @param Content string 正文
     * @param AnchorData array 锚点数组
     * @param AnchorData[0].AnchorId string 锚点Id
     * @param AnchorData[0].Anchor string 锚点名称
     * @param AnchorData[0].Child array 子锚点数组
     */
    addAssistanceDoc:(params)=>{
      return http.post('/help_doc/add',params)
    },
    /**
     * 文章详情
     * @param DocId string 文章Id
     */
    getAssistanceDoc:(params)=>{
      return http.get('/help_doc/detail',params)
    },
    /**
     * 文章发布/取消发布
     * @param DocId number 文章Id
     * @param Status number 状态
     */
    assistanceDocPublish:(params)=>{
      return http.post('/help_doc/publish',params)
    },
    /**
     * 文章发布/取消发布
     * @param DocId number 文章Id
     */
    assistanceDocDelete:(params)=>{
      return http.post('/help_doc/delete',params)
    },
    /**
     * 获取分类列表
     * @param Keyword String分类名称
     * @returns 
     */
    getAssistanceClassifyList:(params)=>{
      return http.get('/help_doc/classify/list',params)
    },
    /**
     * 新增分类
     * @param ParentId number 父节点Id
     * @param HelpDocClassifyName string 添加的目录名称
     */
    addAssistanceClassify:(params)=>{
      return http.post('/help_doc/classify/add',params)
    },
    /**
     * 编辑分类
     * @param HelpDocClassifyId number 节点Id
     * @param ParentId number 父节点Id
     * @param HelpDocClassifyName string 添加的目录名称
     */
    editAssistanceClassify:(params)=>{
      return http.post('/help_doc/classify/edit',params)
    },
    /**
     * 修改分类可见权限
     * @param HelpDocClassifyId number 文章Id
     * @param VisibleBusinessIds number 商家Id 多选 ,拼接
     */
    editAssistanceClassifyVisible:(params)=>{
      return http.post('help_doc/classify/visible/edit',params)
    },
    /**
     * 删除分类
     * @param ClassifyId number 节点Id
     */
    deleteAssistanceClassify:(params)=>{
      return http.get('/help_doc/classify/delete',params)
    },
    /**
     * 移动分类
     * @param ClassifyId number 节点Id
     * @param ParentClassifyId number 父节点Id
     * @param PrevClassifyId number 上一个节点Id 没有为0
     * @param NextClassifyId number 下一个节点Id 没有为0
     */
    moveAssistanceClassify:(params)=>{
      return http.post('/help_doc/classify/move',params)
    },
}