/**
 * 商家管理api
 */
import http from "@/api/http.js"

export const businessCustomInterence = {
    /**
     * 获取商家列表
     * @param Keyword String关键字
     * @param SellerIds String 销售ID（多选），英文逗号拼接
     * @param SigningStatus Integer 签约状态: 1-首次签约; 2-续约中; 3-已终止
     * @param Province String 省份（多选），英文逗号拼接
     * @param City String 城市（多选），英文逗号拼接
     * @param SortParam Integer 排序字段: 1-签约时间; 2-到期时间; 3-创建时间; 4-用户上限
     * @param SortType Integer 排序类型: 1-正序; 2-倒序
     * @param PageSize Integer 每页数据量
     * @param CurrentIndex Integer 页码
     * @returns 
     */
    getBusinessList:(params)=>{
        return http.get('/eta_business/page_list',params)
    },
    /**
     * 获取商家签约列表
     * @param EtaBusinessId Integer 商家ID
     */
    getContractList:(params)=>{
        return http.get('/eta_business/contract_list',params)
    },
    /**
     * 获取操作日志列表
     * @param EtaBusinessId Integer 商家ID
     */
    getTimeLineList:(params)=>{
        return http.get('/eta_business/operate_record_list',params)
    },
    /**
     * 获取商家详情
     * @param EtaBusinessId Integer 商家ID
     */
    getBusinessDetail:(params)=>{
        return http.get('/eta_business/detail',params)
    },
    /**
     * 添加续约
     * @param EtaBusinessId Integer 商家ID
     * @param SigningTime String 签约时间
     * @param ExpiredTime String 到期时间
     * @returns 
     */
    addNewContract:(params)=>{
        return http.post('/eta_business/signing',params)
    },
    /** 
     * 编辑续约
     * @param EtaBusinessId Integer 商家ID
     * @param EtaBusinessContractId Integer 商家合约ID
     * @param SigningTime String 签约时间
     * @param ExpiredTime String 到期时间
     * @returns 
    */
    editContract:(params)=>{
        return http.post('/eta_business/edit_sign',params)
    },
    /**
     * 删除续约信息
     * @param EtaBusinessContractId Integer 商家合约ID
     * @returns 
     */
    removeContract:(params)=>{
        return http.post('/eta_business/remove_sign',params)
    },
    /**
     * 修改销售
     * @param EtaBusinessId Integer 商家ID
     * @param SellerId Integer 销售ID
     * @param SellerName String 销售名称
     */
    changeBusinessSeller:(params)=>{
        return http.post('/eta_business/move_seller',params)
    },
    /**
     * 启用禁用商家
     * @param EtaBusinessId Integer 商家ID
     */
    changeBusinessStatus:(params)=>{
        return http.post('/eta_business/enable',params)
    },
    /**
     * 编辑商家
     * @param EtaBusinessId Integer 商家ID
     * @param Province String 省份
     * @param City String 城市
     * @param Leader String 决策人姓名
     * @param IndustryId Integer 行业ID
     * @param IndustryName String 行业名称
     * @param CapitalScale String 资金规模
     * @param ResearchTeamSize String 研究团队规模
     * @param UserMax Integer 用户上限
     */
    editBusiness:(params)=>{
        return http.post('/eta_business/edit',params)
    },
    /**
     * 添加商家
     * @param BusinessName String 商家名称
     * @param CreditCode String 社会信用码
     * @param RegionType String 所属区域：国内；海外
     * @param Province String 省份
     * @param City String 城市
     * @param SellerId Integer 销售ID
     * @param SellerName String 销售姓名
     * @param Leader String 决策人姓名
     * @param IndustryId Integer 行业ID
     * @param IndustryName String 行业名称
     * @param CapitalScale String 资金规模
     * @param ResearchTeamSize String 研究团队规模
     * @param UserMax Integer 用户上限
     * @param SigningTime String 签约时间（IsCheck为false时必填）
     * @param ExpiredTime String 到期时间（IsCheck为false时必填）
     * @param IsCheck Boolean 是否仅校验，为true时校验参数但不实际新增
     * @returns 
     */
    addBusiness:(params)=>{
        return http.post('/eta_business/add',params)
    },
    /**
     * 获取商家权限详情
     * @param EtaBusinessId 商家ID
     * @returns
     */
    getAuthList:(params)=>{
        return http.get('/eta_business/menu/list',params)
    },
    /**
     * 设置商家权限
     * @param EtaBusinessId 商家ID
     * @param MenuIds 权限的ID列表
     * @returns 
     */
    setAuthList:(params)=>{
        return http.post('/eta_business/menu/relate/save',params)
    },
    /**
     * 获取商家接口权限
     * @returns 
     */
    getConfigList:(params)=>{
        return http.get('/eta_business/api/config/list',params)
    },
    /**
     * 设置商家接口权限
     * @param EtaBusinessId 商家ID
     * @param List 接口权限列表
     * @returns 
     */
    setConfigList:(params)=>{
        return http.post('/eta_business/api/config/set',params)
    }
}