import http from "@/api/http.js"

/* 共享网盘 */

export default {
	/**
	 * 文件目录列表
	 * @param params.MenuId 文件Id 
	 * @param params.Keyword 关键字
	 * @param params.SortType 排序方式: 0-默认; 1-创建时间倒序; 2-创建时间正序
	 * @returns 
	 */
	filelist: params => {
		return http.get('/cloud_disk/list',params)
	},
  /**
	 * 文件目录树状数据
	 * @returns 
	 */
	fileTreeList: () => {
		return http.get('/cloud_disk/menu/tree')
	},
  /**
	 * 新建文件夹
	 * @param params.ParentId 父级目录ID，0为顶级目录
	 * @param params.MenuName 文件夹名称
	 * @returns 
  */
	addFolder: params => {
		return http.post('/cloud_disk/menu/create',params)
	},
  /**
	 * 检验文件是否重命
	 * @param params.MenuId 目录ID
	 * @param params.FileNames 文件名称数组(包含后缀名)
	 * @returns 
  */
	checkFileNamesIsRepeat: params => {
		return http.post('/cloud_disk/resource/check_repeat',params)
	},
  /**
	 * 上传文件
	 * @param params.MenuId 目录ID - formData
	 * @param params.file 文件 - formData
	 * @returns 
  */
	uploadFile: params => {
		return http.post('/cloud_disk/resource/upload',params)
	},
  // /**
	//  * 下载文件
	//  * @param params.MenuId 目录ID
	//  * @returns 
	//  */
	// downloadFileApi: (params) => {
	// 	return http.get('/cloud_disk/menu/download',params,'blob')
	// },
	/**
 * 获取当前目录下的所有文件路径和文件名称
 * @param params.MenuId 目录ID
 * @returns 
 */
	getFilesByMenuId: (params) => {
		return http.get('/cloud_disk/menu/resources',params)
	},
  /**
	 * 文件夹重命名
	 * @param params.MenuId 目录ID
	 * @param params.MenuName 文件夹名称
	 * @returns 
  */
	renameFolder: params => {
		return http.post('/cloud_disk/menu/rename',params)
	},
  /**
	 * 文件重命名
	 * @param params.ResourceId 文件ID
	 * @param params.ResourceName 文件名称
	 * @returns 
  */
	renameFile: params => {
		return http.post('/cloud_disk/resource/rename',params)
	},
    /**
	 * 删除文件夹
	 * @param params.MenuId 目录ID
	 * @returns 
  */
	removeFolder: params => {
		return http.post('/cloud_disk/menu/delete',params)
	},
	/**
	 * 批量删除
	 * @param params.MenuId 目录ID - number
	 * @param params.MenuIds 要删除的目录ID - string [].join(',')
	 * @param params.ResourceIds 要删除文件ID - string [].join(',')
	 * @returns 
  */
	removeFolderBatch: params => {
		return http.post('/cloud_disk/batch_delete',params)
	},
  /**
	 * 删除文件
	 * @param params.ResourceId 文件ID
	 * @returns 
  */
	removeFile: params => {
		return http.post('/cloud_disk/resource/delete',params)
	}
}
