import http from "@/api/http.js";

/* 合同管理模块 */
const contractInterface={
	// 销售更新合同附件
	updateContractFile:params=>{
		return http.post('/contract/update_file',params)
	},

	/**
	 * 上传回签附件
	 */
	uploadCheckFile:params=>{
		return http.post('/contract/upload_check_back_file',params)
	},

	/**
	 * 上传解除协议
	 */
	 uploadRescindFile:params=>{
		return http.post('/contract/upload_rescind_file',params)
	},

	/**
	 * 未提交时的合同下载
	 */
	downloadTemContract:params=>{
		return http.get('/contract/downLoad/tmpContract',params)
	},

	/** 
	 * 获取服务套餐列表
	 * ProductId(可选) 传0或者不传为当前账号权限,1 代表是：ficc；2 代表是：权益
	 */
	getServiceList:params=>{
		return http.get('/contract/service/template/list',params)
	},

	/** 
	 * 获取小套餐中权限选项数据
	 * CompanyType	客户类型：传空字符串或者不传为全部,’ficc’,’权益’
	 */
	getPermissionList:params=>{
		return http.get('/custom/contract_permission/list',params)
	},

	/** 
	 * 合同列表
	 * ContractType			合同类型，枚举值：’新签合同’,’续约合同’,’补充协议’
	 * ContractStatus		合同状态，枚举值：’待提交’,’待审批’,’已撤回’,’已审批’,’已驳回’,’已作废’
	 * ProductId			客户类型：传0或者不传为当前账号权限,1 代表是：ficc；2 代表是：权益
	 * ModifyStartTime		服务更新时间的选择开始时间，格式：2021-05-23 00:00:00
	 * ModifyEndTime		服务更新时间的选择结束时间，格式：2021-05-26 23:59:59
	 * SellerId				选择的销售id
	 * Keyword				搜索关键字
	 */
	getContractList:params=>{
		return http.get('/contract/list',params)
	},

	/** 
	 * 合同详情
	 * ContractId 	合同id
	 */
	getContractDetail:params=>{
		return http.get('/contract/detail',params)
	},

	/** 
	 * 新增合同
	 * 如果是复制模板 则传 SourceId 复制的合同的id
	 * ContractType		合同类型，枚举值：’新签合同’,’续约合同’,’补充协议’
	 * StartDate		开始时间	2021-05-24
	 * EndDate			结束时间	2022-05-24
	 * OriginalPrice	合同金额	120000
	 * Price			优惠后金额
	 * PayRemark		付款方式说明
	 * CompanyName		公司名称
	 * CreditCode		社会信用码
	 * Province			省
	 * City				市
	 * Address			详细地址
	 * Fax				传真
	 * Phone			电话
	 * Postcode			邮编
	 * Remark			补充内容
	 * TemplateId		合同模板 ficc 1 权益 2
	 * Service			服务套餐
	 * IsAudit			false  存草稿  true 直接提交发起审批
	 */
	addContract:params=>{
		return http.post('/contract/add',params)
	},

	/** 
	 * 编辑合同
	 * ReAudit		修改合同并发起审批  false  存草稿  true 直接提交发起审批
	 */
	editContract:params=>{
		return http.post('/contract/edit',{ReAudit:true,...params})
	},

	/** 
	 * 合同模板
	 */
	getContractTemplate:()=>{
		return http.get('/contract/template/list',{})
	},

	/** 
	 * 合同操作记录
	 * ContractId 	合同id编号
	 */
	getContractOperationList:params=>{
		return http.get('/contract/operation/list',params)
	},

	/** 
	 * 提交申请
	 * ContractId 	合同id编号
	 */
	applyContract:params=>{
		return http.get('/contract/approval/apply',params)
	},

	/** 
	 * 撤回申请
	 * ContractApprovalRecordId	审批流id编号
	 * ContractId				合同id编号
	 */
	cancelApplyContract:params=>{
		return http.get('/contract/approval/cancelApply',params)
	},
	
	/** 
	 * 审批列表
	 * ContractType			合同类型，枚举值：’新签合同’,’续约合同’,’补充协议’
	 * Status				合同状态，枚举值：’待审批’,’已审批’,’已驳回’,’已撤回’
	 * ProductId			客户类型：传0或者不传为当前账号权限,1 代表是：ficc；2 代表是：权益
	 * SellerId				选择的销售id
	 * Keyword				搜索关键字
	 */
	getApprovalList:params=>{
		return http.get('/contract/approval/list',params)
	},

	/** 
	 * 获取所属销售列表
	 */
	getSellerList:()=>{
		// return http.get('/custom/seller/check/list',{})
		return http.get('/custom/seller/check/listV2',{})
	},

	/** 
	 * 审批人同意审批
	 * ContractApprovalRecordId			审批流id
	 * NextApproval						是否需要下级批准，预留字段，一期用不到，二期加入合规审批流程的时候，合规审批操作后可能会用到
	 * NextApprovalUserId				是否指定下级审批人，预留字段，一期用不到，二期加入合规审批流程的时候，合规审批操作后可能会用到
	 * Remark							驳回理由
	 */
	contractApplyApproval:params=>{
		return http.post('/contract/approval/approved',params)
	},

	/** 
	 * 审批人拒绝审批
	 * ContractApprovalRecordId			审批流id
	 * Remark							驳回理由
	 */
	 contractApplyReject:params=>{
		return http.post('/contract/approval/reject',params)
	},

	/** 
	 * 删除合同
	 * ContractId			合同id编号
	 */
	contractDelete:params=>{
		return http.get('/contract/delete',params)
	},

	/** 
	 * 作废合同
	 * ContractId			合同id编号
	 */
	contractInvalid:params=>{
		return http.get('/contract/invalid',params)
	},

	/**
	 * 已有合同的预览合同
	 * ContractId			合同id编号
	 */
	previewContractById:params=>{
		return http.get('/contract/previewByContractId',params)
	},

	/** 
	 * 新增合同时的预览
	 */
	previewContract:params=>{
		return http.post('/contract/preview',params)
	},

	// 付款渠道
	getPayChannel:params=>{
		return http.get('/contract/pay_channel/list',params)
	},

	// 业务合同客户名称列表接口
	getBusinessContractCompanyNameList:params=>{
		return http.get('/contract/business_contract/company_name/list/',params)
	},
	// 根据客户名称获取所有已签回的业务合同列表接口
	getBusinessContractList:params=>{
		return http.get('/contract/business_contract/list/',params)
	},

	// 新增合同时根据信用码确定合同类型
	getContractTypeByCode:params=>{
		return http.get('/custom/detail_by_credit_code',params)
	},
	//获取历史合同
	getHistoryContract:params=>{
		return http.get('/custom/company/last_contract/detail/withoutDate',params)
	},
	// 合同列表接口
	getAllocationContract:params=>{
		return http.get('/cygx/allocation/company_contract_list',params)
	},
	// 申请服务更新-签约历史(单个详情)
	getHistoryDetail:params=>{
		return http.get('/custom/apply/contract/history/detail',params)
	},
	// 派点详情
	getAllocationDetail:params=>{
		return http.get('/cygx/allocation/detail',params)
	},
	// 更新派点接口
	getAllocationDetailUpdate:params=>{
		return http.post('/cygx/allocation/update',params)
	},
	// 派点统计
	getAllocationStatistic:params=>{
		return http.get('/cygx/allocation/statistics',params)
	},
	// 订单列表接口
	getOrderList:params=>{
		return http.get('/cygx/order/list',params)
	},
	// 退款
	orderRefund:params=>{
		return http.post('/cygx/order/refund',params)
	},
	// 退款记录
	orderRefundList:params=>{
		return http.get('/cygx/order/refund/list',params)
	},
	// 退款撤销接口
	refundRevokeOrder:params=>{
		return http.get('/cygx/order/refund_revoke',params)
	},
}

export {
	contractInterface
}