import http from "@/api/http.js"

/* 数据管理模块 */
const dataInterence = {
	/**
	 * 研究员 指标列表
	 * Frequency	频度
	 * TradeCode
	 * ClassifyId	分类id
	 * EdbShowType	指标展示类型： 0：不管有没有数据，指标都展示出来， 1：只展示有数据的指标， 2：只展示没有数据的指标
	 */
	getTargetList:params=>{
		return http.get('/entry/target/item_list',params)
	},

	/** 
	 * 删除 整行数据
	 * CreateDate		日期
	 * TradeCodeList	指标code 列表
	 */
	deleteTargetByDate:params=>{
		return http.post('/entry/data/batch_delete_by_date',params)
	},

	/** 
	 * 删除指标
	 * TradeCode
	 */
	deleteTargetByCode:params=>{
		return http.post('/entry/data/batch_delete',params)
	},
	
	/**
	 * 搜索接口
	 * Frequency 	频度
	 * ClassifyId	分类id
	 * Keyword
	 * EdbShowType
	 */
	getTargetListByName:params=>{
		return http.get('/entry/target/item_name_list',params)
	},

	/**
	 * 指标频度列表
	 * ClassifyId	分类id
	 */
	getFrequencyList:params=>{
		return http.get('/entry/target/frequency_list',params)
	},

	// 指标单位
	getTargetUnitList:params=>{
		return http.get('/entry/target/unit_list',params)
	},

	// 获取分类列表
	getClassify: params => {
		return http.get('/entry/classify',params)
	},
	/*  录入指标
	classify_id int	分类id
	frequency string	频度
	unit		string	单位
	sec_name	string 指标名称 */
	addTarget: params => {
		return http.post('/entry/target/add',params)
	},
	/* 编辑指标
	trade_code		string	唯一编码
	classify_id		int	分类id
	frequency		string	频度
	unit		string	单位
	sec_name		string	指标名称 */
	editTarget: params => {
      return http.post('/entry/target/edit',params)
	},
	/* 指标列表接口
	page_no	int	每页起始位置：默认0
	page_size	int	每页数据条数，默认10
	start_date	string	开始日期
	end_date	string	结束日期
	frequency	string	频度
	classify_id	int	分类id，默认0
	key_word	string	标题搜索关键词 */
	targetList:params => {
      return http.get('/entry/target/list',params)
	},
	/* 搜索指标接口
	classify_id	是	int	分类id
	key_word	是	string	名称关键词	 */
	searchTarget:params => {
      return http.get('/entry/target/search',params)
	},
	/* 录入数据
	trade_code	是	string	指标唯一编码
	create_date	是	string	创建日期
	close	是	string	录入值 */
	addData:params => {
		return http.post('/entry/data/add',params)
	},
	/* 编辑数据
	trade_code	是	string	指标唯一编码
	create_date	是	string	创建日期
	close	是	string	录入值 */
	editData:params => {
		return http.post('/entry/data/edit',params)
	},
	/* 删除数据
	trade_code	是	string	指标唯一编码
	create_date	是	string	数据录入日期 */
	delData:params => {
		return http.post('/entry/data/delete',params)
	},
/* 	获取数据列表
	page_no	是	int	每页起始位置：默认0
	page_size	是	int	每页数据条数，默认10
	start_date	否	string	开始日期
	end_date	否	string	结束日期
	frequency	否	string	频度
	classify_id	否	int	分类id，默认0
	key_word	否	string	标题搜索关键词 
	trade_code	否	string	指标编码 */
	getDatalist:params => {
		return http.get('/entry/data/list',params)
	},
/* 	导出数据
	start_date	否	string	开始日期
	end_date	否	string	结束日期
	frequency	否	string	频度
	classify_id	否	int	分类id，默认0
	key_word	否	string	标题搜索关键词 */
	exportData:params => {
		return http.get('/entry/export/dataList',params)
	},
/* 	检测日期下数据是否存在接口
	trade_code	是	string	指标唯一编码
	create_date	是	string	所选日期 */
	checkData:params => {
		return http.get('/entry/data/check',params)
	},
	// 检测指标是否包含数据接口
	// trade_code
	checkTarget:params => {
		return http.get('/entry/target/check',params)
	},
	/* 删除指标接口
	trade_code */
	delTarget:params => {
		return http.post('/entry/target/delete',params)
	},
	// 获取研究员列表
	getResearcher:params => {
		return http.get('/entry/getResearcher',params)
	},
	/* 获取指标
	mobile	是	string	手机号码 */
	getTarget:params => {
		return http.get('/entry/getTargetItems',params)
	},

	// 手工数据录入中批量修改录入数据
	modifyTargetDate:params=>{
		return http.post('/entry/data/batch_edit',params)
	},

	// 上海期货交易所
	getShFuturesData:params=>{
		return http.get('/entry/data/shfe',params)
	},

	// 大连交易所数据
	getDlExchangeData:params=>{
		return http.get('/entry/data/dalian',params)
	},

	// 郑州交易所数据
	getZzExchangeData:params=>{
		return http.get('/entry/data/zhengzhou',params)
	},

	// 中国金融期货交易所
	getChinaFuturesData:params=>{
		return http.get('/entry/data/cffex',params)
	},

	// 谷歌出行指数 获取最新的日期
	getGoogleTravelLastDate:params=>{
		return http.get('/datamanage/visitors_covid/last_date',params)
	},

	// 谷歌出行指数 获取数据
	getGoogleTravelData:params=>{
		return http.get('	/datamanage/visitors_covid/list',params)
	},
	
	// 上海国际能源交易中心
	getShEnergyData:params=>{
		return http.get('/entry/data/ine',params)
	},

	// 获取研究所分类 Exchange
	/* 	cffex 中金所
		shanghai 上期所
		ine 上海能源交易所
		dalian 大连
		zhengzhou 郑州*/
	getResearcherClassifyList:params=>{
		return http.get('/entry/data/exchange/classify',params)
	},

	// 获取合约号
	// Exchange Classify
	getExchangeClassifyContract:params=>{
		return http.get('/entry/data/exchange/classifyContract',params)
	},

	// 欧洲天然气 获取父级
	getGasEicContinent:params=>{
		return http.get('/entry/data/eicContinent',params)
	},

	//获取欧洲天然气子级数据
	getGasData:params=>{
		return http.get('/entry/data/eicData',params)
	},

	//获取最新一条有数据的日期
	getGasLasteTime:params=>{
		return http.get('/entry/data/eicLatestDate',{})
	},

	// 获取天然气历史数据
	getGasHistoryData:params=>{
		return http.get('/entry/data/eicHistoryData',params)
	},
	//欧洲天然气-获取最新一条有数据的日期
	getGasLasteTimeV2:params=>{
		return http.get('/entry/data/eicLatestDateV2',{})
	},
	// 欧洲天然气 获取父级
	getGasEicContinentV2:params=>{
		return http.get('/entry/data/eicDataV2',params)
	},
	// 获取天然气历史数据
	getGasHistoryDataV2:params=>{
		return http.get('/entry/data/eicHistoryDataV2',params)
	},
	//获取欧洲天然气子级数据
	getGasDataV2:params=>{
		return http.get('/entry/data/eicSSODataV2',params)
	},
	/**
	 * 复制excel保存
	 * @param {*} params luckysheet 
	 * @returns 
	*/
	saveOnlineExcel: params => {
		return http.post('/entry/target/excel_style/add',params)
	},

	/**
	 * 复制excel保存 - 编辑
	 * @param {*} params luckysheet 
	 * @returns 
	*/
	editOnlineExcel: params => {
		return http.get('entry/target/excel_style/edit',params)
	},
	// ------------UN数据源
	/**
	 * 获取国家数据 
	 */
	getUNCountryData: () => {
		return http.get('datamanage/com_trade/country/list')
	},
	/**
	 * 获取指标数据列表
	 * @param params.CurrentIndex 页码- number
	 * @param params.PageSize 每页数据量- number
	 * @param params.IndexCode 指标编码- String
	 * @param params.Year 年份- String
	 * @param params.Flow 流向- X（Export：出口）；M（Import：进口）
	 * @param params.ReporterCode 出口国id- number
	 * @param params.PartnerCode 进口国id- number
	 */
	getUNCodeData: (params) => {
		return http.get('datamanage/com_trade/data/list',params)
	},	
	/**
 * 根据指标编码 模糊搜索获取指标编码列表
 * @param params.Keyword 关键字- string
 */
	getIndexCodeData: (params) => {
		return http.get('datamanage/com_trade/list',params)
	}
}

/* 手工数据权限 */
const dataAuthInterface = {
	/**
	 * 获取分类权限列表
	 * @param {AdminId} params 
	 * @returns 
	 */
	authList: params => {
		return http.get('/datamanage/manual/classify/all',params);
	},
	/**
	 * 获取研究员
	 * @param {*} params 
	 * @returns 
	 */
	userList: params => {
		return http.get('/datamanage/manual/sysuser/all',params)
	},
	/**
	 * 保存权限
	 * @param {AdminId} params 
	 * @param {ClassifyId} params 
	 * @returns 
	 */
	saveAuth: params => {
		return http.post('/datamanage/manual/sysuser/classify/save',params)
	},
	/**
	 * 用户检索
	 * @param {KeyWord} params 
	 * @returns 
	 */
	userSearch:params => {
		return http.get('/datamanage/manual/sysuser/search',params)
	},
	/**
	 * 新增分类
	 * @param {ClassifyName} params 
	 * @param {ParentId} params 
	 * @returns 
	 */
	classifyAdd: params => {
		return http.post('/datamanage/manual/classify/add',params)
	},
	/**
	 * 修改分类名称
	 * @param {ClassifyName} params 
	 * @param {ClassifyId ParentId} params 
	 * @returns 
	 */
	classifyEdit: params => {
		return http.post('/datamanage/manual/classify/edit',params)
	},
	/**
	 * 手工数据 获取自己的品种分类
	 * @param {*} params 
	 * @returns 
	 */
	classifyList: params => {
		return http.get('/datamanage/manual/set_classify/all',params);
	},

	/**
	 * 删除分类
	 * @param {ClassifyId} params 
	 * @returns 
	 */
	classifyDel: params => {
		return http.post('/datamanage/manual/classify/delete',params)
	},

	/**
	 * 一级分类
	 * @param {*} params 
	 * @returns 
	 */
	classifyOne: params => {
		return http.get('/datamanage/manual/classify/first',params)
	},

	/**
	 * 所有分类
	 * @param {*} params 
	 * @returns 
	 */
	classifyAll: params => {
		return http.get('/datamanage/manual/classify/all_list',params)
	}
}

export {
	dataInterence,
	dataAuthInterface
}