import http from "@/api/http.js"

/* ficc活动管理 */
export const ficcManageInterface={
	/**
	 * 获取活动分类列表
	 */
	activityTypeList:()=>{
		return http.get('/yb/activity/type/list',{})
	},

	/**
	 * 活动列表
	 * @param Keyword
	 * @param ActivityTypeId	活动类别id
	 * @param ActiveStatus	活动进行状态，枚举值：1：未开始；2：进行中；3：已结束
	 * @param PublishStatus	活动发布状态，枚举值：-1：全部；0：未发布；1：已发布
	 * @param StartDate
	 * @param EndDate
	 */
	activityList:params=>{
		return http.get('/yb/activity/list',params)
	},

	/**
	 * 活动发布
	 * @param ActivityId
	 */
	activityPublish:params=>{
		return http.post('/yb/activity/publish',params)
	},

	/**
	 * 活动取消发布
	 * @param ActivityId
	 */
	activityUnPublish:params=>{
		return http.post('/yb/activity/unpublish',params)
	},

	/**
	 * 删除活动
	 * @param ActivityId
	 */
	activityDelete:params=>{
		return http.post('/yb/activity/del_publish',params)
	},

	/**
	 * 获取主讲人列表
	 */
	activitySpeakerList:params=>{
		return http.get('/yb/speaker/list',params)
	},

	/**
	 * 获取报告列表
	 */
	activityReportList:params=>{
		return http.get('/yb/report/list',params)
	},

	/**
	 * 新增活动
	 */
	activityAdd:params=>{
		return http.post('/yb/activity/add',params)
	},

	/**
	 * 编辑活动
	 */
	activityEdit:params=>{
		return http.post('/yb/activity/edit',params)
	},

	/**
 	 * 活动报名列表
 	 * @param {TypeCode} params
 	 */	
	 activitySignupList: params => {
		return http.get('/yb/activity_register/list',params);
	},
	/**
 	 * 活动报名详情
 	 * @param {TypeCode} params
 	 */	
	 activitySignupDetailList: params => {
		return http.get('/yb/activity_register_user/list',params);
	},
	/**
 	 * 查询系统中可以报名的联系人列表
 	 * @param {TypeCode} params
 	 */	
	 activitySignupUserList: params => {
		return http.get('/yb/user/list',params);
	},
	/**
 	 * 新增用户报名活动
 	 * @param {TypeCode} params
 	 */	
	 activitySignupAddUser: params => {
		return http.post('/yb/activity_register/add',params);
	},
	/**
 	 * 取消用户活动报名
 	 * @param {TypeCode} params
 	 */	
	 activitySignupCancelUser: params => {
		return http.post('/yb/activity_register/cancel',params);
	},
	/**
 	 * 获取活动详情
 	 * @param {TypeCode} params
 	 */	
	 activityDetail: params => {
		return http.get('/yb/activity/detail',params);
	},

	/**
 	 * 获取申请列表
 	 * @param {TypeCode} params
 	 */	
	 applyRecordList: params => {
		return http.get('/yb/apply_record/list',params);
	},
	/**
 	 * 获取用户申请列表
 	 * @param {TypeCode} params
 	 */	
	 applyRecordListV2: params => {
		return http.get('/yb/apply_record/listV2',params);
	},
	/**
	 * 导出用户申请列表
	 * @param {TypeCode} params 
	 */
	exportRecordListV2:params=>{
		return http.get('yb/apply_record/listV2/export',params)
	},
	/**
 	 * 处理申请记录
 	 * @param {TypeCode} params
 	 */	
	 applyRecordDeal: params => {
		return http.post('/yb/apply_record/mark_handle',params);
	},
	/* ficc申请单移动潜在用户
		"BusinessCardUrl":string名片地址
		"CompanyId": int,
		"DepartmentName":string联系人部门
		"Email": "string",
		"IsMaker":int是否决策人，1:是，0:否
		"Mobile": "string",
		"Position":	string职位
		"RegionType":string 区域，枚举值：国内、海外
		"RealName": "string",
		"Remark": "string",
		"SellerId":int 需要移动到的销售id
		"Sex":int 用户性别，1为男性，2为女性
		"UserId": int
		"ApplyRecordId":int
	*/
	moveUserByApplyRecord:params => {
		return http.post('/custom/potential/user/moveByApplyRecord',params)
	},

	//全时会议创建
	quanshiEventCreate:params => {
		return http.post('yb/activity/create_qs',params)
	},
	//全时会议取消
	quanshiEventCancel:params => {
		return http.post('yb/activity/cancel_qs',params)
	},
	//到会列表
	quanshiAttendList:params => {
		return http.get('yb/activity/quanshi/list',params)
	},
	//到会详情
	quanshiAttendDetail:params => {
		return http.get('yb/activity/quanshi/user_list',params)
	},

	//进门到会列表
	jmAttendList:params => {
		return http.get('yb/activity/comein/list',params)
	},
	//进门到会详情
	jmAttendDetail:params => {
		return http.get('yb/activity/comein/user_list',params)
	},
	//用户申请列表-删除潜在用户
	delPotentialUser:params=>{
		return http.post('yb/potential/user/del',params)
	},

	// 添加、编辑主讲人
	saveSpeaker:params=>{
		return http.post('/yb/speaker/save',params)
	},

	//删除主讲人
	delSpeaker:params=>{
		return http.post('/yb/speaker/del',params)
	},

	//删除主讲人校验
	delSpeakerCheck:params=>{
		return http.post('/yb/speaker/del_check',params)
	},
  //全时会议分享销售
  qs_shareSeller:params=>{
    return http.post('/yb/activity/qs_share2seller',params)
  },
  //进门到会分享销售
  jm_shareSeller:params=>{
    return http.post('/yb/activity/comein/share2seller',params)
  }
}