/**
 * 海外客户管理
 */
import http from "@/api/http.js"

export const overseasCustomInterence = {
    /**
     * 获取已保存的销售
     * @param {*} params 
     */
    getSavedSalesList:(params)=>{
        return http.get('/overseas_custom/sale/list',params)
    },
    /**
     * 保存已选择的销售
     * @param {Object} params 
     * @param {Number[]} params.AddSellerIdArr 新增销售id
     * @param {Number[]} params.DelSellerIdArr 删除销售id
     * @returns 
     */
    saveSelectedSales:(params)=>{
        return http.post('/overseas_custom/sale/save',params)
    },
    /**
     * 获取海外客户统计数据
     * @param {*} params 
     * @returns 
     */
    getCustomStatus:(params)=>{
        return http.get('/overseas_custom/custom/statistics',params)
    },
    /**
     * 获取海外客户列表数据
     * @param {Object} params 
     * @param {String} params.CompanyStatus 客户状态:全部,正式,试用,关闭
     * @param {String} params.SellerId 销售id ,拼接
     * @param {Number} params.CustomType 客户类型:1 海外客户 2 隐藏的客户
     * @param {String} params.SortField 排序字段:ViewTotal,RoadShowTotal,CreateTime
     * @param {Number} params.SortDesc 排序类型:1 降序(默认) 2 升序
     * @param {String} params.Keywords 
     * @param {Number} params.CurrentIndex
     * @param {Number} params.PageSize
     * @returns 
     */
    getCustomList:(params)=>{
        return http.get('/overseas_custom/custom/list',params)
    },
    /**
     * 设置客户试用子标签
     * @param {Object} params 
     * @param {Number} params.CompanyId 客户id
     * @param {Number} params.OverseasLabel 海外客户试用子标签：1未分类、2  推进、3 跟踪、4 预备
     * @returns 
     */
    setCustomTryStatus:(params)=>{
        return http.post('/overseas_custom/custom/overseas_label_set',params)
    },
    /**
     * 设置客户隐藏/取消隐藏
     * @param {Object} params 
     * @param {Number} params.CompanyId
     * @returns 
     */
    setCustomHide:(params)=>{
        return http.post('/overseas_custom/custom/hide',params)
    },
    /**
     * 设置客户状态为正式/重置
     * @param {Object} params
     * @param {Number} params.CompanyId
     * @returns 
     */
    setCustomStatus:(params)=>{
        return http.post('/overseas_custom/custom/status_set',params)
    },
    /**
     * 获取客户统计信息
     * @param {Object} params
     * @param {String} params.Keywords
     * @param {String} params.SellerId
     * @param {Number} params.CustomType
     * @returns 
     */
    getStatisticData:(params)=>{
        return http.get('/overseas_custom/custom/statistics',params)
    },
    /**
     * 获取客户试用统计信息
     * @param {Object} params
     * @param {String} params.Keywords
     * @param {String} params.SellerId
     * @param {Number} params.CustomType
     * @returns 
     */
    overseasCustomInterence:(params)=>{
        return http.get('/overseas_custom/custom/label/statistics',params)
    },
    
    /**
     * 海外客户路演 销售 研究列表
     * @param {*} params AdminType： researcher seller
     * @returns 
     */
    getOverseasRoadShowUsers: params => {
        return http.get('/roadshow/overseas_custom/sys_user/list',params)
    },

    /**
     * 海外客户路演列表 - 客户维度
     * @param {*} params 
     * ResearcherId SellerId  StartDate EndDate  CompanyStatus
     * @returns 
     */
    getOverseasRoadShowList: params => {
        return http.get('/roadshow/overseas_custom/calendar/list',params)
    },
    /**
     * 海外客户路演列表 - 销售维度
     * @param {*} params 
     * DataType StartDate EndDate
     * @returns 
    */
    getOverseasSellerRoadShowList: params => {
        return http.get('/roadshow/overseas_custom/seller/list',params)
    },
    /**
     * 海外客户路演列表 - 研究员维度
     * @param {*} params 
     * DataType StartDate EndDate
     * @returns 
    */
    getOverseasResearcherRoadShowList: params => {
        return http.get('/roadshow/overseas_custom/researcher/list',params)
    }

}