import http from "@/api/http.js"
/**
 * 图库9.0(智能PPT版式) 接口
 */
export default{
    /**
     * ppt列表
     * KeyWord:string 搜索关键字
     */
    getpptList:params=>{
        return http.get('/pptv2/list',params)
    },
    /**
     * 新增ppt
     * FirstPage:{Title,ReportType,PptDate,ImgUrl} 封面信息
     * Content:string ppt具体内容,转字符串
     * GroupId:目录id
     */
    addppt:params=>{
        return http.post('/pptv2/add',params)
    },
    /** 
     * 编辑ppt
     * PptId
     * FirstPage
     * Content
     */
    editppt:params=>{
        return http.post('/pptv2/edit',params)
    },
    /**
     * 删除ppt
     * PptId
     */
    deleteppt:params=>{
        return http.post('/pptv2/delete',params)
    },
    /**
     * 获取ppt详情
     * PptId
     */
    getpptDetail:params=>{
        return http.get('/pptv2/detail',params)
    },
    /**
     * 上传ppt文件
     *  FormData:PptId
     *  FormData:file
     */
    uploadPPTXFile:params=>{
        return http.post('/pptv2/pptUpload',params)
    },
    /**
     * 发布ppt
     * PptId
     * PptxUrl
     */
    publishPPT:params=>{
        return http.post('/pptv2/publish',params)
    },
    /**
     * 定时保存
     * PptId
     * FirstPage
     * Content
     */
    saveLog:params=>{
        return http.post('/pptv2/saveLog',params)
    },
    /**
     * 获取PPT配置
     */
    getConfig:params=>{
        return http.get('/pptv2/config',params)
    },
    /**
     * ppt目录列表
     * IsNewPpt:是否只展示新版ppt：1展示，0不展示，不传默认0
     */
    getCatalogsList:params=>{
        return http.get('/pptv2/groups',params)
    },
    /**
     * ppt目录列表(私有) 
     */
    getPrivateCatalogList:params=>{
      return http.get('pptv2/group/name',params)
    },
    /**
     * 新增ppt目录
     * GroupName:目录名称
     */
    addCatalog:params=>{
        return http.post('/pptv2/group/add',params)
    },
    /**
     * 重命名ppt目录
     * GroupId:目录Id
     * GroupName:目录名称
     */
    renameCatalog:params=>{
        return http.post('/pptv2/group/rename',params)
    },
    /**
     * 删除ppt目录
     * GroupId
     */
    deleteCatalog:params=>{
        return http.post('/pptv2/group/delete',params)
    },
    /**
     * 共享/取消共享ppt目录
     * GroupId
     */
    shareCatalog:params=>{
        return http.post('/pptv2/group/share',params)
    },
    /**
     * 复制ppt目录
     * GroupId
     */
    copyCatalog:params=>{
        return http.post('/pptv2/group/copy',params)
    },
    /**
     * 共享/取消共享单个ppt
     * GroupPptId:目录和ppt绑定序号
     */
    sharePPT:params=>{
        return http.post('/pptv2/share',params)
    },
    /**
     * ppt目录列表内容(私有目录)
     * GroupId:目录ID
     */
    getCatalogListByGroupId:params=>{
        return http.get('/pptv2/group/ppt/list',params)
    },
    /**
     * ppt目录列表内容(公有/私有目录)
     * AdminId:分享人Id/KeyWorld:ppt标题/IsPrivate:true/false 是否查询私有目录
     */
    getCatalogListByAdminId:params=>{
      return http.get('/pptv2/share/ppt/list',params)
    },
    searchPPTByKeyWorld:params=>{
      return http.get('/pptv2/share/ppt/list',params)
    },
    /**
     * 移动目录里的ppt
     * GroupPptId
     * PrevGroupPptId:上一个ppt和目录的绑定序号,置顶则0
     * NextGroupPptId:下一个ppt和目录的绑定序号,置尾则0
     * GroupId
     */
    movePPT:params=>{
        return http.post('/pptv2/move',params)
    },
    /**
     * 移动目录
     * PrevGroupId:上一个目录Id,置顶则0
     * NextGroupId:下一个目录Id,置尾则0
     * GroupId
     */
    moveCatalog:params=>{
        return http.post('/pptv2/group/move',params)
    },
    /**
     * 复制单个ppt
     * PptId
     * GroupId
     */
    copyPPT:params=>{
        return http.post('/pptv2/copy',params)
    },
    /**
     * 搜索单个PPT
     * KeyWord
     */
    searchPPT:params=>{
        return http.get('/pptv2/group/ppt/search',params)
    },
    /**
     * ppt转双周报
     */
    transReport:params=>{
        return http.post('/pptv2/to_report',params)
    },

    /**
     * 设置共享
     * @param {*} params 
		 * PptId 
		 * GrantType  1：全部ficc研究员；2：指定成员
		 * AdminIdStr
     */
    setShareAuth: params => {
      return http.post('/pptv2/grant',params)
    },
		
    /**
     * 取消共享
     * @param {*} params  PptId
     * @returns 
     */
    cancelShareAuth: params => {
        return http.post('/pptv2/grant/cancel',params)
    },

    /**
     * 获取分配列表
     * @param {*} params GroupId
     */
    getSharedList: params => {
        return http.get('/pptv2/grant/ppt/list',params)
    },
    
    /**
     * 获取分配ppt详情
     * @param {*} params PptId
     * @returns 
     */
    getSharedDetail: params => {
        return http.get('/pptv2/grant/info',params)
    },

    /**
     * 单个PPT转英文PPT
     * @param {*} params PptId GroupId
     * @returns 
     */
    transPPTtoEn:params=>{
      return http.post('pptv2/toEn',params)
    },

    /**
     * 多个PPT转英文PPT
     * @param {*} params PptIds GroupId
     * @returns 
     */
    transCatalogtoEn:params=>{
      return http.post('pptv2/batchToEn',params)
    }

}
