import http from "@/api/http.js";
import timeLineApi from "./timeLine.js";
import raiReport from "./reportApi";
import raiBanner from "./bannerApi.js";
import internalInterface from "./internalApi.js";
import lableApi from "./lableApi.js";
import raiPoints from "./pointsApi.js";
import voteApi from "./voteApi.js";
import YanXuanApi from "./YanXuanApi.js";
/* 权益小程序管理 */
const raiInterface = {
  ...raiReport,
  ...timeLineApi,
  ...raiBanner,
  ...internalInterface,
  ...lableApi,
  ...raiPoints,
  ...voteApi,
  ...YanXuanApi,
  /* 
		优化建议列表
		PageSize CurrentIndex KeyWord  
	*/
  adviceList: (params) => {
    return http.get("/cygx/advice/list", params);
  },
  /* 
		行业图谱
	*/
  getMap: (params) => {
    return http.get("/cygx/industry/map/list", params);
  },
  /* 
		新增节点  
		"IndustryMapId": 0,
		"IndustryMapName": "string" 
	*/
  addNode: (params) => {
    return http.post("/cygx/industry/map/add", params);
  },
  /* 
		删除节点 "IndustryMapId": 0
	*/
  delNode: (params) => {
    return http.post("/cygx/industry/map/delete", params);
  },
  /* 
		修改节点名称 "IndustryMapId": 0  IndustryMapName
	*/
  editNode: (params) => {
    return http.post("/cygx/industry/map/edit", params);
  },
  /* 
		访谈申请列表
		PageSize CurrentIndex KeyWord  
	*/
  interviewList: (params) => {
    return http.get("/cygx/interview/list", params);
  },
  /* 
		取消访谈/申请访谈
		HandleType 1 更新 2 取消 InterviewApplyId InterviewTime
	*/
  cancelInterview: (params) => {
    return http.post("/cygx/interview/status/modify", params);
  },
  /* 
		权益申请列表 PageSize CurrentIndex KeyWord CustomType 
	*/
  applyList: (params) => {
    return http.get("/cygx/apply/record/list", params);
  },
  /* 处理申请 */
  delApply: (params) => {
    return http.post("/cygx/apply/record/deal", params);
  },
  /* 获取产业管理一级分类接口 */
  chartPermission: (params) => {
    return http.get("/cygx/chartPermission/first", params);
  },
  /* 获取产业详情 */
  industrialManagementDetailIs: (params) => {
    return http.get("/cygx/industrialManagement/industrialManagementDetail", params);
  },

  /*产业管理
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   *************************分析师模块*********************/

  /**
   * 产业管理添加分析师
   * @param {AnalystName } params 分析师名称
   * @param {IndustrialManagementId } params  产业id
   * @returns
   */
  industrialAnalyst: (params) => {
    return http.post("/cygx/industrialAnalyst/add", params);
  },
  /**
   * 获取分析师列表接口
   * @param {IndustrialManagementId } params  产业id
   * @returns
   */
  getIndustrialAnalyst: (params) => {
    return http.get("/cygx/industrialAnalyst/list", params);
  },
  /**
   * 编辑分析师列表接口
   * @param {AnalystName } params  分析师名称
   * @param {CreateTime } params  创建时间
   * @param {IndustrialAnalystId } params  分析师id
   * @param {IndustrialManagementId } params  产业id
   * @returns
   */
  industrialAnalystEdit: (params) => {
    return http.post("/cygx/industrialAnalyst/edit", params);
  },
  /**
   * 删除分析师列表接口
   * @param {IndustrialManagementId } params  产业id
   * @returns
   */
  industrialAnalystDelete: (params) => {
    return http.post("/cygx/industrialAnalyst/delete", params);
  },

  /*产业管理
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   *************************产业管理模块*********************/

  /**
   * 产业管理添加产业接口
   * @param {ChartPermissionId } params  分类ID
   * @param {IndustryName } params  产业名称
   * @param {IsNewLabel } params  是否属于新标签，1是，0否
   * @param {LayoutTime } params  布局时间
   * @param {RecommendedIndex } params  推荐指数
   * @returns
   */
  industrialManagement: (params) => {
    return http.post("/cygx/industrialManagement/add", params);
  },
  /**
   * 产业管理编辑产业接口
   * @param {ChartPermissionId } params  分类ID
   * @param {IndustryName } params  产业名称
   * @param {IsNewLabel } params  是否属于新标签，1是，0否
   * @param {LayoutTime } params  布局时间
   * @param {RecommendedIndex } params  推荐指数
   * @param {IndustrialManagementId } params  产业id
   * @param {IsDeepLabel } params  是否属于深度标签，1是，0否
   * @param {RecommendedIndex } params  推荐指数
   * @returns
   */
  industrialManagementEdit: (params) => {
    return http.post("/cygx/industrialManagement/edit", params);
  },
  /**
   * 获取产业列表接口
   * @param {ChartPermissionId } params  分类ID
   * @param {OrderColumn } params  排序字段 ，AddTime添加时间 ，Recommended推荐指数 ，ReportTime 报告更新时间
   * @returns
   */
  getIndustrialManagement: (params) => {
    return http.get("/cygx/industrialManagement/list", params);
  },
  /**
   * 删除产业列表接口
   * @param {IndustrialManagementId } params  产业ID
   * @returns
   */
  getIndustrialManagementDelete: (params) => {
    return http.post("/cygx/industrialManagement/delete", params);
  },
  /*产业管理
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   *************************标的模块*********************/

  /**
   * 获取标的列表接口
   * @param {IndustrialManagementId } params  产业ID
   * @returns
   */
  getIndustrialSubject: (params) => {
    return http.get("/cygx/industrialSubject/list", params);
  },
  /**
   * 添加标的列表接口
   * @param {IndustrialManagementId } params  产业ID
   * @param {SubjectName } params  标的名称
   * @returns
   */
  industrialSubjectAdd: (params) => {
    return http.post("/cygx/industrialSubject/add", params);
  },
  /**
   * 修改标的列表接口
   * @param {IndustrialManagementId } params  产业ID
   * @param {SubjectName } params  标的名称
   * @param {CreateTime } params  创建时间
   * @param {IndustrialSubjectId } params  标的id
   * @returns
   */
  industrialSubjectEdit: (params) => {
    return http.post("/cygx/industrialSubject/edit", params);
  },
  /**
   * 删除标的
   * @param {IndustrialManagementId } params  产业ID
   * @returns
   */
  industrialSubjectDelete: (params) => {
    return http.post("/cygx/industrialSubject/delete", params);
  },

  /*********************报告管理模块的接口*******************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * ********************************************************
   * */

  /**
   * 获取主题
   * @param {ChartPermissionId } params  分类ID
   * @returns
   */
  reportMappingist: (params) => {
    return http.get("/cygx/reportMappingist/list", params);
  },
  /**
   * 获取列表
   * @param {PageSize } params
   * @param {CurrentIndex } params
   * @param {KeyWord } params
   * @param {IsFilter } params  是否过滤 ，1是，0否，不传默认为0
   * @param {IsClass } params  是否归类 ，1是，0否 ，不传默认为0
   * @param {ChartPermissionId } params  行业ID --> 一级分类列表中 ChartPermissionId
   * @param {SubCategoryName } params  主题
   * @param {MatchTypeName } params  报告匹配类型
   * @param {IndustrialManagementId } params  产业ID
   * @param {StartDate } params  开始时间用0 补齐，列如2021-03-06 08:09:01
   * @param {EndDate } params  结束时间用0 补齐，列如2021-03-06 08:09:01
   * @returns
   */
  reportArticle: (params) => {
    return http.get("/cygx/reportArticle/list", params);
  },
  /**
   * 过滤报告
   * @param {ReportId } params  报告ID
   * @returns
   */
  reportArticleFilter: (params) => {
    return http.post("/cygx/reportArticle/filter", params);
  },
  /**
   * 报告归类
   * @param {IndustrialManagementId } params  产业ID
   * @param {ReportId } params  报告ID
   * @param {IndustrialSubjectIdStr } params  标的id多个用 , 逗号隔开 1,2
   * @returns
   */
  reportArticleClassification: (params) => {
    return http.post("/cygx/reportArticle/classification", params);
  },
  /**
   * 报告归类
   * @returns
   */
  reportMappingMatchTypeRep: (params) => {
    return http.get("/cygx/reportMappingMatchTypeRep/list", params);
  },
  /**
   * 获取是否展示操作按钮接口
   * @returns
   */
  getshowButton: (params) => {
    return http.get("/cygx/reportArticle/showButton", params);
  },
  /**
   * 获取7天热词列表接口
   * @param {PageSize } params
   * @param {CurrentIndex } params
   * @returns
   */
  hostKeyword: (params) => {
    return http.get("/cygx/hostKeyword/list", params);
  },
  /**
   * 获取权限
   * @returns
   */
  hostKeywordCanDownload: (params) => {
    return http.get("/cygx/hostKeyword/canDownload", params);
  },
  /**
   * 获取一级分类不带策略
   * @returns
   */
  getNoTacticsfirst: (params) => {
    return http.get("/cygx/chartPermission/noTacticsfirst", params);
  },
    /**
   * 专项调研活动行业分类接口
   * @returns
   */
    getActivitySpecial: (params) => {
      return http.get("/cygx/chartPermission/activitySpecial", params);
    },
  /**
   * 通过多个产业获取标的列表接口
   * @param {IndustrialManagementIdStr } params 分类ID，多个使用 ,隔开列如 1,3,5
   * @returns
   */
  getindustrialSubjectlistIds: (params) => {
    return http.get("/cygx/industrialSubject/listIds", params);
  },
  /**
   * 通过多个产业获取标的列表接口
   * @param {IndustrialManagementId } params 产业ID
   * @returns
   */
  industrialManagementDetail: (params) => {
    return http.get("/cygx/industrialManagement/detail", params);
  },
  /*********************纪要的接口*******************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * ********************************************************
   * */

  /**
   * 纪要的保存与发布接口
   * @param {IndustrialManagementId } params 产业ID
   * @param {Abstract } params 摘要
   * @param {Body } params 内容
   * @param {ChartPermissionIds } params 行业ID 多个逗号
   * @param {Department } params 作者
   * @param {DoType } params 操作类型 0，保存 、1，发布
   * @param {SellerAndMobile } params 销售和手机号
   * @param {SummaryManageId } params 纪要ID 等于0新增纪要，大于0修改纪要
   * @param {Title } params 标题
   * @returns
   */
  preserveAndPublish: (params) => {
    return http.post("/cygx/summaryManage/PreserveAndPublish", params);
  },
  /**
   * 获取一级分类（包含其它）接口
   * @returns
   */
  noTacticsfirstOther: (params) => {
    return http.get("/cygx/chartPermission/noTacticsfirstOther", params);
  },
  /**
   * 获取纪要列表接口
   * @param {PageSize } params
   * @param {CurrentIndex } params
   * @param {KeyWord } params
   * @param {PublishStatus } params  发布状态 ，0未发布，1已发布，传2查询所有
   * @param {CategoryName } params  行业名称
   * @param {StartDate } params  开始时间用0 补齐，列如2021-03-06 08:09:01
   * @param {EndDate } params  结束时间用0 补齐，列如2021-03-06 08:09:01
   * @returns
   */
  getsummaryManageList: (params) => {
    return http.get("/cygx/summaryManage/list", params);
  },
  /**
   * 获取纪要详情接口
   * @param {SummaryManageId } params  纪要ID
   * @returns
   */
  getsummaryManagedetail: (params) => {
    return http.get("/cygx/summaryManage/detail", params);
  },
  /**
   * 删除纪要接口
   * @param {SummaryManageId } params  纪要ID
   * @returns
   */
  getsummaryManagedelete: (params) => {
    return http.post("/cygx/summaryManage/delete", params);
  },
  /**
   * 纪要的发布与取消发布接口
   * @param {SummaryManageId } params  纪要ID
   * @returns
   */
  publishAndCancel: (params) => {
    return http.post("/cygx/summaryManage/PublishAndCancel", params);
  },
  /**
   * 获取提问列表详情接口
   * @param {SummaryManageId } params  纪要ID
   * @returns
   */
  summaryManageAskList: (params) => {
    return http.get("/cygx/summaryManage/commentList", params);
  },
  /**
   * 作者关注列表
   * @returns
   */
  departmentFollowList: (params) => {
    return http.get("/cygx/summaryManage/department/followList", params);
  },

  /**
   * 收藏
   * @returns
   */
  articleCollection: (params) => {
    return http.get("/cygx/summaryManage/articleCollection", params);
  },
  /*********************活动的接口*******************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * ********************************************************
   * */

  /**
   * 活动类型列表接口
   * @returns
   */
  getActivityType: (params) => {
    return http.get("/cygx/activityType/list", params);
  },
  /**
   * 活动类型详情接口
   * @param {ActivityTypeId } params  活动ID
   * @returns
   */
  activityTypeDetail: (params) => {
    return http.get("/cygx/activityType/detail", params);
  },
  /**
   * 活动客户列表接口
   * @returns
   */
  customerTypelist: (params) => {
    return http.get("/cygx/activity/customerTypelist", params);
  },
  /**
   * 活动内容的保存与发布接口
   * @param {ActivityId } params 活动ID 等于0新增活动，大于0修改活动
   * @param {ActivityTypeId } params 活动类型id
   * @param {Body } params 内容
   * @param {CustomerTypeIds } params 活动可见的客户类型，多个ID用 , 隔开
   * @param {LimitPeopleNum } params 限制的人数数量
   * @param {DoType } params 操作类型 0，保存 、1，发布
   * @param {PermissionName } params 行业名称
   * @returns
   */
  preserveAndPublishAdd: (params) => {
    return http.post("/cygx/activity/PreserveAndPublish", params);
  },
  /**
   * 获取列表
   * @param {PageSize } params
   * @param {CurrentIndex } params
   * @param {KeyWord } params
   * @param {StartDate } params  开始时间用0 补齐，列如2021-03-06 08:09:01
   * @param {EndDate } params  结束时间用0 补齐，列如2021-03-06 08:09:01
   * @param {PublishStatus } params  发布状态 ，1未发布，1已发布，传2查询所有
   * @param {ActivityTypeId } params  活动类型id
   * @param {ChartPermissionId } params  行业ID -
   * @param {ActiveState } params  活动进行状态 未开始：NotStarted、进行中HaveInHand、已结束Complete
   * @returns
   */
  //获取纪要列表接口
  getActivityList: (params) => {
    return http.get("/cygx/activity/list", params);
  },
  /**
   * 删除活动的接口
   * @param {ActivityTypeId } params  活动ID
   * @returns
   */
  activityDelete: (params) => {
    return http.post("/cygx/activity/delete", params);
  },
  /**
   * 活动的发布与取消发布接口
   * @param {ActivityTypeId } params  活动ID
   * @returns
   */
  activityPublishAndCancel: (params) => {
    return http.post("/cygx/activity/PublishAndCancel", params);
  },
  /**
   * 获取活动详情接口
   * @param {ActivityTypeId } params  活动ID
   * @returns
   */
  activityDetail: (params) => {
    return http.get("/cygx/activity/detail", params);
  },
  /**
   * 获取活动详情接口
   * @param {MeetType } params  会议类型 1线上、2线下
   * @returns
   */
  activityTypeMeetType: (params) => {
    return http.get("/cygx/activityType/meetType", params);
  },
  /**
   * 获取活动类型列表小分类筛选接口
   * @param {SearchType } params  筛选类型 1专家/分析师嗲话会、2专家/分析师线下沙龙 、3公司调研/
   * @returns
   */
  activitySignuplistSearch: (params) => {
    return http.get("/cygx/activityType/listSearch", params);
  },

  /*********************报名管理的接口*******************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * ********************************************************
   * */

  /**
   * 获取报名管理列表接口
   * @param {PageSize } params
   * @param {CurrentIndex } params
   * @param {KeyWord } params
   * @param {StartDate } params  开始时间用0 补齐，列如2021-03-06 08:09:01
   * @param {EndDate } params  结束时间用0 补齐，列如2021-03-06 08:09:01
   * @param {PublishStatus } params  发布状态 ，1未发布，1已发布，传2查询所有
   * @param {ActivityTypeId } params  活动类型id 隔开列如: 1,2
   * @param {ChartPermissionId } params  行业ID -
   * @param {SearchType } params  筛选类型 1专家/分析师电话会、2专家/分析师线下沙龙 、3公司调研/
   * @returns
   */
  activitySignup: (params) => {
    return http.get("/cygx/activitySignup/list", params);
  },
  /**
   * 获取预约外呼详情列表接口
   * @param {ActivityId } params  活动ID
   * @returns
   */
  appointmentList: (params) => {
    return http.get("/cygx/activitySignup/appointmentList", params);
  },
  /**
   * 获取外呼人员列表接口
   * @returns
   */
  activitySignupUserList: (params) => {
    return http.get("/cygx/activitySignup/userList", params);
  },
  /**
   * 新增外呼人员接口
   * @param {ActivityIds } params  活动id,多个用,隔开
   * @param {UserIds } params  用户id,多个用,隔开
   * @returns
   */
  activitySignupAddUser: (params) => {
    return http.post("/cygx/activitySignup/addUser", params);
  },
  /**
   * 获取报名失败详情列表接口
   * @param {ActivityId } params  活动id
   * @returns
   */
  salonFailSignupList: (params) => {
    return http.get("/cygx/activitySignup/salonFailSignupList", params);
  },
  /**
   * 修改公司调研电话会限制报名、预约外呼、自主拨入接口
   * @param {Id } params
   * @param {OperationStatus } params
   * @returns
   */
  callSignupEdit: (params) => {
    return http.post("/cygx/activitySignup/callSignupEdit", params);
  },
  /**
   * 修改沙龙限制报名、加入报名接口
   * @param {Id } params
   * @returns
   */
  salonSignupEdit: (params) => {
    return http.post("/cygx/activitySignup/salonSignupEdit", params);
  },
  /**
   * 新增报名人员接口
   * @param {ActivityIds } params
   * @param {UserIds } params
   * @returns
   */
  activitySignupAddSignuUser: (params) => {
    return http.post("/cygx/activitySignup/addSignuUser", params);
  },
  /**
   * 获取单条报名详情接口
   * @param {Id } params
   * @returns
   */
  activitySignupSignupDetail: (params) => {
    return http.get("/cygx/activitySignup/signupDetail", params);
  },
  /**
   * 新增报名人员（可择报名方式）接口
   * @param {ActivityIds } params
   * @param {JsonStar } params
   * @returns
   */
  addSignuUserOptType: (params) => {
    return http.post("/cygx/activitySignup/addSignuUserOptType", params);
  },
  /**
   * 活动取消报名接口
   * @param {SignupId } params
   * @returns
   */
  activitySignupApply: (params) => {
    return http.post("/cygx/activitySignup/cancel", params);
  },
  /**
   * 修改外呼号码接口
   * @param {CountryCode } params
   * @param {OutboundMobile } params
   * @param {Id } params
   * @returns
   */
  outboundMobileEdit: (params) => {
    return http.post("/cygx/activitySignup/outboundMobileEdit", params);
  },
  /**
   * 获取带问列表详情接口
   * @param {ActivityId } params
   * @returns
   */
  activitySignupAskList: (params) => {
    return http.get("/cygx/activitySignup/askList", params);
  },

  /*********************到会管理的接口*******************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * *********************************************************
   * ********************************************************
   * */

  //获取到会管理列表接口
  activityMeetList: (params) => {
    return http.get("/cygx/activityMeet/list", params);
  },
  //获取线下报名详情列表接口
  offlineListDetail: (params) => {
    return http.get("/cygx/activityMeet/offlineListDetail", params);
  },
  //获取线下报名详情列表接口
  activityMeetmeetingDo: (params) => {
    return http.post("/cygx/activityMeet/meetingDo", params);
  },
  //获取爽约记录接口
  breakAppointmentList: (params) => {
    return http.get("/cygx/activityMeet/breakAppointment", params);
  },
  //获取爽约记录详情接口
  breakAppointmentDetail: (params) => {
    return http.get("/cygx/activityMeet/breakAppointmentDetail", params);
  },
  //获取销售接口
  sellerNameListList: (params) => {
    return http.get("/cygx/activityMeet/sellerNameList", params);
  },
  //提交线下到会情况接口
  signUpRestrictUid: (params) => {
    return http.post("/cygx/activityMeet/signUpRestrictUid", params);
  },
  //上传参会表格数据
  activityMeetImport: (params) => {
    return http.post("/cygx/activityMeet/importYidong", params);
  },
  //获取线上到会详情接口
  attendanceDetail: (params) => {
    return http.get("/cygx/activityMeet/attendanceDetail", params);
  },
  //获取线上到会详情接口
  activityMeetoffline: (params) => {
    return http.get("/cygx/activityMeet/offlineMeetingList", params);
  },

  //纪要获取敏捷搜索关键词的列表接口
  fastSearchKeWordsummaryManage: (params) => {
    return http.get("/cygx/summaryManage/fastSearchKeWord", params);
  },
  //纪要新增和修改敏捷搜索关键词的列表接口
  editFastSearchKeWordsummary: (params) => {
    return http.post("/cygx/summaryManage/editFastSearchKeWord", params);
  },
  //获取永续客户是否展示详情接口
  sustainableDetailSummaryManage: (params) => {
    return http.get("/cygx/summaryManage/sustainableDetail", params);
  },
  //修改永续客户是否展示接口
  sustainableEditSummaryManage: (params) => {
    return http.post("/cygx/summaryManage/sustainableEdit", params);
  },

  //获取活动敏捷搜索关键词的列表接口
  activityFastSearchKeWord: (params) => {
    return http.get("/cygx/activity/fastSearchKeWord", params);
  },

  //获取活动行业分类接口
  chartPermissionList: (params) => {
    return http.get("/cygx/activity/chartPermission/list", params);
  },
  //研选报告列表接口
  reportArticleresearchList: (params) => {
    return http.get("/cygx/reportArticle/research/list", params);
  },
  //研选报告详情接口
  reportArticleDetail: (params) => {
    return http.get("/cygx/reportArticle/detail", params);
  },
  //研选报告列表接口
  reportPreserveAndPublish: (params) => {
    return http.post("/cygx/reportArticle/PreserveAndPublish", params);
  },
  //研选报告的发布与取消发布接口
  reportArticlePublishAndCancel: (params) => {
    return http.post("/cygx/reportArticle/PublishAndCancel", params);
  },
  //删除研选报告接口
  reportArticleDelete: (params) => {
    return http.post("/cygx/reportArticle/delete", params);
  },
  //获取提问列表详情接口
  reportArticleAskList: (params) => {
    return http.get("/cygx/reportArticle/askList", params);
  },
  /**
   * 通过报告ID获取对应的匹配类型接口
   * @param {ReportId } params  报告ID
   * @returns
   */
  getMatchTypeName: (params) => {
    return http.get("/cygx/reportArticle/getMatchTypeName", params);
  },
  //修改报告的匹配类型接口
  updateMatchTypeName: (params) => {
    return http.post("/cygx/reportArticle/updateMatchTypeName", params);
  },
  //获取关联作者列表接口
  departmentList: (params) => {
    return http.get("/cygx/reportArticle/departmentList", params);
  },

  //获取关联产业列表接口
  industrialManagementListByName: (params) => {
    return http.get("/cygx/industrialManagement/listByName", params);
  },
  //获取关联标的列表接口
  industrialSubjectListByName: (params) => {
    return http.get("/cygx/industrialSubject/listByName", params);
  },
  /* 上周、本周、路演精华 模块  */
  /**
   * 获取带有图标的一级分类接口
   * @param {Havestrategy} params 是否有策略，1有，0无 默认无
   * @returns
   */
  chartPermissionFirstHaveIco: (params) => {
    return http.get("/cygx/chartPermission/firstHaveIco", params);
  },
  /**
   * 获取带有图标的一级分类接口
   * @param {Havestrategy} params 是否有策略，1有，0无 默认无
   * @returns
   */
  chartPermissiondetailTemplate: (params) => {
    return http.get("/cygx/researchSummary/detailTemplate", params);
  },
  /**
   * 获取研究汇总列表接口
   * @param {PageSize} params
   * @param {CurrentIndex} params
   * @param {PublishStatus} params 发布状态 ，1未发布，1已发布，传2查询所有
   * @param {StartDate} params
   * @param {EndDate} params
   * @returns
   */
  researchSummaryList: (params) => {
    return http.get("/cygx/researchSummary/list", params);
  },
  /**
   * 研究汇总的发布与取消发布接口
   * @param {ArticleId} params
   * @returns
   */
  researchSummaryPublishAndCancel: (params) => {
    return http.post("/cygx/researchSummary/PublishAndCancel", params);
  },
  /**
   * 删除研究汇总内容接口
   * @param {ArticleId} params
   * @returns
   */
  researchSummaryDelete: (params) => {
    return http.post("/cygx/researchSummary/delete", params);
  },
  /**
	 * 研究汇总内容的保存与发布接口
	 * @param {Abstract} params 
	 * @param {ArticleId} params 
	 * @param {Content} params 
	 * ListBzchjh:	[...]
		ListCydyjy:	[...]
		ListSdbg:	[...]
		ListSjdp:	[...]
		SortBzchjh:	string
		本周晨会精华排序
		SortCydyjy:	string
		产业调研纪要排序
		SortSdbg:	string
		深度报告排序
		SortSjdp:	string
		事件点评排序
	 * @param {Department} params 
	 * @param {DoType} params 
	 * @param {PublishDate} params 
	 * @param {Title} params 
	 * @returns 
	 */
  researchSummaryPreserveAndPublish: (params) => {
    return http.post("/cygx/researchSummary/PreserveAndPublish", params);
  },
  /**
   * 研究汇总内容详情接口
   * @param {ArticleId} params
   * @returns
   */
  researchSummaryDetail: (params) => {
    return http.get("/cygx/researchSummary/detail", params);
  },
  /**
   * 路
   * 演
   * 精
   * 华
   * 模
   * 块
   */
  /**
   * 研究汇总内容详情接口
   * @param {PageSize} params
   * @param {CurrentIndex} params
   * @param {PublishStatus} params
   * @param {StartDate} params
   * @param {EndDate} params
   * @param {KeyWord} params
   * @param {ChartPermissionId} params
   * @returns
   */
  roadshowEssenceList: (params) => {
    return http.get("/cygx/roadshowEssence/list", params);
  },
  /**
   * 路演精华的发布与取消发布接口
   * @param {ArticleId} params
   * @returns
   */
  roadshowEssencePublishAndCancel: (params) => {
    return http.post("/cygx/roadshowEssence/PublishAndCancel", params);
  },
  /**
   * 路演精华的删除
   * @param {ArticleId} params
   * @returns
   */
  roadshowEssenceDelete: (params) => {
    return http.post("/cygx/roadshowEssence/delete", params);
  },
  /**
   * 研究汇总内容的保存与发布接口
   * @param {ArticleId} params
   * @returns
   */
  roadshowEssencePreserveAndPublish: (params) => {
    return http.post("/cygx/roadshowEssence/PreserveAndPublish", params);
  },
  /**
   * 路演精华内容详情接口
   * @param {ArticleId} params
   * @returns
   */
  roadshowEssenceDetail: (params) => {
    return http.get("/cygx/roadshowEssence/detail", params);
  },
  /**
   * 报
   * 告
   * 精
   * 选
   * 模
   * 块
   */
  /* 获取报告精选列表接口
   * @param {PageSize} params
   * @param {CurrentIndex} params
   * @param {PublishStatus} params
   * @param {StartDate} params
   * @param {EndDate} params
   * @returns
   */
  reportSelectionList: (params) => {
    return http.get("/cygx/reportSelection/list", params);
  },
  /**
   * 删除报告精选内容接口
   * @param {ArticleId} params
   * @returns
   */
  reportSelectionDelete: (params) => {
    return http.post("/cygx/reportSelection/delete", params);
  },
  /**
   * 报告精选的发布与取消发布接口
   * @param {ArticleId} params
   * @returns
   */
  reportSelectionPublishAndCancel: (params) => {
    return http.post("/cygx/reportSelection/PublishAndCancel", params);
  },
  /**
   * 报告精选内容详情接口
   * @param {ArticleId} params
   * @returns
   */
  reportSelectionDetail: (params) => {
    return http.get("/cygx/reportSelection/detail", params);
  },
  /**
   * 报告精选内容详情接口
   * @param {ArticleId} params
   * @returns
   */
  reportSereportSelectiondDetailTemplate: (params) => {
    return http.get("/cygx/reportSelection/detailTemplate", params);
  },
  /**
   * 通过行业获取关联标的列表接口
   * @param {ArticleId} params
   * @returns
   */
  industrialSubjectSearch: (params) => {
    return http.get("/cygx/industrialSubject/search", params);
  },
  /**
   * 报告精选内容的保存与发布接口
   * @param {ArticleId} params
   * @returns
   */
  industrialSubjectPreserveAndPublish: (params) => {
    return http.post("/cygx/reportSelection/PreserveAndPublish", params);
  },
  /**
   *  获取期数
   * @param {ArticleId} params
   * @returns
   */
  industrialSubjectListPeriods: (params) => {
    return http.get("/cygx/reportSelection/listPeriods", params);
  },
  /**
   *  获取综述报告
   * @param {ArticleId} params
   * @returns
   */
  getReportSelectionArticle: (params) => {
    return http.get("/cygx/reportSelection/getArticle", params);
  },

  /**
   * 上
   * 周
   * 纪
   * 要
   * 模
   * 块
   */
  /* 获取报告精选列表接口
   * @param {PageSize} params
   * @param {CurrentIndex} params
   * @param {PublishStatus} params
   * @param {StartDate} params
   * @param {EndDate} params
   * @returns
   */
  minutesSummaryList: (params) => {
    return http.get("cygx/minutesSummary/list", params);
  },
  /* 获取报告精选列表接口
   * @param {ArticleId} params
   * @returns
   */
  minutesSummaryPublishAndCancel: (params) => {
    return http.post("/cygx/minutesSummary/PublishAndCancel", params);
  },
  /* 获取报告精选列表接口
   * @param {ArticleId} params
   * @returns
   */
  minutesSummaryDelete: (params) => {
    return http.post("/cygx/minutesSummary/delete", params);
  },
  /**
	 * 上周纪要汇总内容的保存与发布接口
	 * @param {Abstract} params 
	 * @param {ArticleId} params 
	 * @param {Content} params 
	 * ListBzchjh:	[...]
		ListCydyjy:	[...]
		ListSdbg:	[...]
		ListSjdp:	[...]
		SortBzchjh:	string
		本周晨会精华排序
		SortCydyjy:	string
		产业调研纪要排序
		SortSdbg:	string
		深度报告排序
		SortSjdp:	string
		事件点评排序
	 * @param {Department} params 
	 * @param {DoType} params 
	 * @param {PublishDate} params 
	 * @param {Title} params 
	 * @returns 
	 */
  minutesSummaryPreserveAndPublish: (params) => {
    return http.post("/cygx/minutesSummary/PreserveAndPublish", params);
  },
  /* 获取报告精选列表接口
   * @param {ArticleId} params
   * @returns
   */
  minutesSummaryDetail: (params) => {
    return http.get("cygx/minutesSummary/detail", params);
  },
  /* 获取线上活动进门财经关联匹配列表接口
   * @param {KeyWord} params
   * @returns
   */
  activityMeetMatchingList: (params) => {
    return http.get("cygx/activityMeet/matchingList", params);
  },
  /* 手动匹配线上客户参会记录接口
   * @param {KeyWord} params
   * @param {ActivityId} params
   * @returns
   */
  activityMeetMatchingByHand: (params) => {
    return http.post("cygx/activityMeet/matchingByHand", params);
  },
  // 获取一级分类所关联的产业列表接口
  getListIndustrial: (params) => {
    return http.get("cygx/chartPermission/listIndustrial", params);
  },
  // 查找标的
  industrialSubjectSearch: (params) => {
    return http.get("cygx/industrialSubject/search", params);
  },
  // 查找标的 标的详情搜索
  industrialSubjectSearchInfo: (params) => {
    return http.get("/cygx/industrialSubject/searchInfo", params);
  },
  //线上到会管理 备注列表接口
  activityMeetRemarkList: (params) => {
    return http.get("/cygx/activityMeet/remark/list", params);
  },
  //线上到会管理 新增备注接口
  activityMeetAddRemarks: (params) => {
    return http.post("/cygx/activityMeet/addRemarks", params);
  },
  //线上到会管理 阅读记录列表接口
  activityMeetHistoryList: (params) => {
    return http.get("/cygx/activityMeet/history/list", params);
  },
  //线上到会管理 上传停留时间
  activityMeetAddStopTime: (params) => {
    return http.post("/cygx/activityMeet/addStopTime", params);
  },
  //会议提醒人数详情列表接口
  activitySignupReminder: (params) => {
    return http.get("/cygx/activitySignup/reminder/list", params);
  },
  //预约纪要详情列表接口
  activitySignupSummaryList: (params) => {
    return http.get("/cygx/activitySignup/appointment/summaryList", params);
  },
  //取消纪要纪要预约接口
  activityAppointmentCancel: (params) => {
    return http.post("/cygx/activitySignup/appointment/cancel", params);
  },
  //取消会议提醒接口
  activityReminderCancel: (params) => {
    return http.post("/cygx/activitySignup/reminder/cancel", params);
  },
  //新增预约纪要人员接口
  activityAddSummaryUser: (params) => {
    return http.post("/cygx/activitySignup/appointment/addSummaryUser", params);
  },
  //文章类型列表接口
  summaryManageArticleType: (params) => {
    return http.get("/cygx/summaryManage/articleType/list", params);
  },
  //添加文章类型列表接口
  addSummaryManageArticleType: (params) => {
    return http.post("/cygx/summaryManage/articleType/add", params);
  },
  //研选移动产业
  industrialManagementMove: (params) => {
    return http.post("/cygx/industrialManagement/move", params);
  },
  //标的-报告活动数量详情
  industrialSubjectCountDetail: (params) => {
    return http.get("/cygx/industrialSubject/countDetail", params);
  }, //本周研究汇总 群发邮件
  researchSummarySendMail: (params) => {
    return http.get("/cygx/researchSummary/sendMail", params);
  },
  //上周纪要汇总 群发邮件
  minutesSummarySendMail: (params) => {
    return http.get("/cygx/minutesSummary/sendMail", params);
  },
  //获取流失且参加过会议的参会明细接口
  getActivityLossCompany: (params) => {
    return http.get("/cygx/activityLoss/company/list", params);
  },
  //获取流失且参加过会议的用户
  getActivityLossUser: (params) => {
    return http.get("/cygx/activityLoss/user/list", params);
  },
  //获取流失且参加过会议的参会明细接口
  getActivityLossMeet: (params) => {
    return http.get("/cygx/activityLoss/meet/list", params);
  },

  /* 上传图片接口 formData  */
  upload: (params) => {
    return http.post("/resource/image/upload", params);
  },
  /**
   * 晨
   * 会
   * 管
   * 理
   * 模
   * 块
   */
  //获取晨会精华列表 PageSize CurrentIndex KeyWord MeetingTime Status
  getMorningMeetingList: (params) => {
    return http.get("/cygx/morningMeeting/list", params);
  },
  //晨会列表-发布 ReviewId
  publishListMeeting: (params) => {
    return http.post("/cygx/morningMeeting/publish", params);
  },
  //晨会列表-取消发布 ReviewIds
  cancelPublish: (params) => {
    return http.post("/cygx/morningMeeting/publish/cancel", params);
  },
  //晨会列表-删除 ReviewId
  deleteListMeeting: (params) => {
    return http.post("/cygx/morningMeeting/delete", params);
  },
  //获取晨会精华详情 MeetingId
  getMorningMeetingDetail: (params) => {
    return http.get("/cygx/morningMeeting/detail", params);
  },
  //发布晨会精华  DoType: 1发布;
  publishMorningMeeting: (params) => {
    return http.post("/cygx/morningMeeting/preserveAndPublish", { ...params, ...{ DoType: 1 } });
  },
  //保存/新增 MeetingId:为0时是新增 DoType: 0保存
  editMorningMeeting: (params) => {
    return http.post("/cygx/morningMeeting/preserveAndPublish", { ...params, ...{ DoType: 0 } });
  },
  // 发送模板消息
  activitySignupTempMsg: (params) => {
    return http.post("/cygx/activitySignup/tempMsg", params);
  },
  // 发送模板消息
  activityTripSignupTempMsg: (params) => {
    return http.post("/cygx/special/trip/tempMsg", params);
  },
  // 模版消息发送客户类型列表
  activitySendGroupList: (params) => {
    return http.get("/cygx/activitySignup/tempMsg/sendGroupList", params);
  },
  // 模版消息发送客户类型列表
  activityTripSendGroupList: (params) => {
    return http.get("/cygx/special/trip/tempMsg/sendGroupList", params);
  },
  // 根据图片获取建会信息接口
  activityImgToText: (params) => {
    return http.post("/cygx/activity/imgToText", params);
  },
};

/* 权益小程序管理 专项调研模块*/
const raiSpecial = {
  //专项调研内容的保存与发布接口
  specialPreserveAndPublish: (params) => {
    return http.post("/cygx/special/PreserveAndPublish", params);
  },
  //活动的发布与取消发布接口
  specialPublishAndCancel: (params) => {
    return http.post("/cygx/special/PublishAndCancel", params);
  },
  //删除活动接口
  specialDelete: (params) => {
    return http.post("/cygx/special/delete", params);
  },
  //获取活动详情接口
  specialDetail: (params) => {
    return http.get("/cygx/special/detail", params);
  },
  //获取活动详情接口
  specialInterested: (params) => {
    return http.get("/cygx/special/interested/list", params);
  },
  //获取活动列表接口
  getSpecialList: (params) => {
    return http.get("/cygx/special/list", params);
  },
  //获取活动列表接口
  getSpecialSpecialList: (params) => {
    return http.get("/cygx/special/signup/list", params);
  },
  //确定行程编辑接口
  postSpecialTripPreserveAndPublish: (params) => {
    return http.post("/cygx/special/trip/PreserveAndPublish", params);
  },
  //活动下线与重新发布
  postSpecialOffline: (params) => {
    return http.post("/cygx/special/Offline", params);
  },
  //新增报名接口
  addUserSpecial: (params) => {
    return http.post("/cygx/special/trip/addUser", params);
  },
  //报名列表/下载接口
  getSpecialtripList: (params) => {
    return http.get("/cygx/special/tripList", params);
  },
  //取消报名
  cancelSpecialtripList: (params) => {
    return http.post("/cygx/special/trip/cancel", params);
  },
  //到会详情
  getSpecialtripmeetDetial: (params) => {
    return http.get("/cygx/special/trip/meetDetial", params);
  },
  //提交到会情况
  postSpecialtripMeetingDo: (params) => {
    return http.post("/cygx/special/trip/meetingDo", params);
  },
  outboundMobileEdit: (params) => {
    return http.post("/cygx/special/trip/outboundMobileEdit", params);
  },
};

/* 商品晨报 */
const morningPaper = {
  //文章列表
  getList: (params) => {
    return http.get("/advisory/article/list", params);
  },
  //获取分类的列表
  getmyfllow: (params) => {
    return http.get("/advisory/getmyfllow", params);
  },
  //删除文章
  articleDelete: (params) => {
    return http.post("/advisory/article/delete", params);
  },
  //发布文章
  articleFirstadd: (params) => {
    return http.post("/advisory/article/firstadd", params);
  },
  //取消发布
  articleUnpublish: (params) => {
    return http.post("/advisory/article/unpublish", params);
  },
  //保存咨询
  articlePreservation: (params) => {
    return http.post("/advisory/article/preservation", params);
  },
  //文章详情
  articleDetail: (params) => {
    return http.get("/advisory/article/detail", params);
  },
  //pv uv
  getPVAndUv: (params) => {
    return http.get("/advisory/getPVAndUv", params);
  },
};

export { raiInterface, morningPaper, raiSpecial };
