import http from "@/api/http.js"

/* 隆众数据库 */
const lzDataInterface = {
	/**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */
	classifyList: params => {
		return http.get('/datamanage/lz/classify',params);
	},
	/**
	 * 数据列表
	 * @param {BreedId} params 分类id
	 * @param {Frequency } params
	 * @returns 
	 */
	dataList: params => {
		return http.get('/datamanage/lz/data',params);
	},
	/**
	 * 频度列表
	 * @param {BreedId} params 
	 */
	frequencyList: params => {
		return http.get('/datamanage/lz/frequency',params);
	},

	// 隆重指标搜索接口
	getTargetListByName:params=>{
		return http.get('/datamanage/lz/search_list',params)
	},

}

/* 钢联数据库 */
const glDataInterface = {
	/**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */
	classifyList: params => {
		return http.get('/datamanage/gl/classify',params);
	},
	/**
	 * 数据列表
	 * @param {BreedShortName } params 分类id
	 * @param {Frequency } params
	 * @returns 
	 */
	dataList: params => {
		return http.get('/datamanage/gl/data',params);
	},
	/**
	 * 频度列表
	 * @param {BreedShortName } params 
	 */
	frequencyList: params => {
		return http.get('/datamanage/gl/frequency',params);
	},

	// 钢联指标搜索接口
	getTargetListByName:params=>{
		return http.get('/datamanage/gl/search_list',params)
	},
	// 钢联单个指标数据列表
	getTargetDataList:params=>{
		return http.get('/datamanage/gl/single_data',params)
	},
}

/* 有色数据库 */
const smmDataInterface = {
	/**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */
	classifyList: params => {
		return http.get('/datamanage/smm/classify',params);
	},
	/**
	 * 获取指标目录详情
	 * @param {ClassifyId}  分类id
	 * @param {Frequency}  频度名称
   * @param {CurrentIndex}
   * @param {PageSize}
	 * @returns 
	 */
	dataList: params => {
		return http.get('/datamanage/smm/data',params);
	},
	/**
	 * 频度列表
	 * @param {TypeCode} params 
	 */
	frequencyList: params => {
		return http.get('/datamanage/smm/frequency',params);
	},

	// smm指标搜索接口
	getTargetListByName:params=>{
		return http.get('/datamanage/smm/search_list',params)
	},
	/**
	 * 获取单个指标详情
	 * @param {IndexCode}  指标id
	 * @returns 
	 */
	getTargetDataList:params=>{
		return http.get('/datamanage/smm/single_data',params)
	},
  /**
	 * 添加分类
	 * @param {ParentId} 上级id 为0表示是一级分类
   * @param {ClassifyName} 分类名称
	 */
  addClassifyItem:params=>{
    return http.post('/datamanage/smm/classify/add',params)
  },
  /**
	 * 编辑分类
	 * @param {ClassifyId} 分类id
   * @param {ClassifyName} 分类名称
	 */
   editClassifyItem:params=>{
     return http.post('/datamanage/smm/classify/edit',params)
   },
   /**
	 * 删除分类
	 * @param {ClassifyId} 分类id
	 */
  deleteClassifyItem:params=>{
    return http.post('/datamanage/smm/classify/del',params)
  },
  /**
   * 分类名称列表
   */
  classifyNameList:params=>{
    return http.get('/datamanage/smm/classify/name',params)
  },
  /**
	 * 编辑指标分类（移动指标）
	 * @param {ClassifyId} 分类id
   * @param {BaseFromSmmIndexId} 指标id
	 */
  editSmmTarget:params=>{
    return http.post('/datamanage/smm/edit',params)
  },
  /**
	 * 移动目录
	 * @param {ClassifyId} 分类id
   * @param {ParentId} 上级id
   * @param {PrevClassifyId} 上一个兄弟节点分类id 若移动到第一个 为0
   * @param {NextClassifyId} 下一个兄弟节点分类id 若移动到最后一个 为0
	 */
  moveCatalog:params=>{
    return http.post('/datamanage/smm/classify/move',params)
  },
  /**
	 * 移动指标
	 * @param {ClassifyId} 分类id
   * @param {BaseFromSmmIndexId} 指标id
   * @param {PrevBaseFromSmmIndexId} 上一个兄弟节点分类id 若移动到第一个 为0
   * @param {NextBaseFromSmmIndexId} 下一个兄弟节点分类id 若移动到最后一个 为0
	 */
  moveSMMtarget:params=>{
    return http.post('/datamanage/smm/move',params)
  },
  /**
	 * 删除指标
   * @param {BaseFromSmmIndexId} 指标id
	 */
  deleteSMMtarget:params=>{
    return http.post('/datamanage/smm/del',params)
  },
  /**
	 * 清除指标分类
   * @param {BaseFromSmmIndexId} 指标id
	 */
  cleanClassify:params=>{
    return http.post('/datamanage/smm/reset',params)
  }
}

/* 中国煤炭网 */
const coalDataInterface = {
	/**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */
	 classifyList: params => {
		return http.get('/entry/data/coalMineData/classify',params);
	},
	/**
	 * 中国煤炭网数据列表
	 * @param {ClassifyId } params 分类id
	 * @param {Frequency } params
	 * @param {GroupName } params
	 * @returns 
	 */
	dataList: params => {
		return http.get('/entry/data/coalMineData/data',params);
	},
	/**
	 * 频度列表
	 * @param {ClassifyId } params 
	 */
	frequencyList: params => {
		return http.get('/entry/data/coalMineData/frequency',params);
	},

	// 中国煤炭网指标搜索接口
	getTargetListByName:params=>{
		return http.get('/entry/data/coalMineData/search',params)
	},
	// 中国煤炭网单个指标数据列表
	getTargetDataList:params=>{
		return http.get('/entry/data/coalMineData/single_data',params)
	},

}

/* 钢联化工 */
const steelInterface = {
	/**
	 * 分类列表
	 * @param {*} params 
	 * @returns 
	 */
	classifyList: params => {
		return http.get('/datamanage/mysteel_chemical/classify')
	},

	/**
	 * 编辑分类 ClassifyName BaseFromMysteelChemicalClassifyId ParentId  Level
	 * @param {*} params 
	 * @returns 
	 */
	classifyEdit: params => {
		return http.post('/datamanage/mysteel_chemical/classify/edit',params)
	},

	/**
	 * 新增分类
	 * @param {*} params ClassifyName ParentId  Level
	 * @returns 
	 */
	classifyAdd: params => {
		return http.post('/datamanage/mysteel_chemical/classify/add',params)
	},

	/**
	 * 删除分类
	 * @param {*} params BaseFromMysteelChemicalClassifyId
	 * @returns 
	 */
	classifyDel: params => {
		return http.post('/datamanage/mysteel_chemical/classify/del',params)
	},

	/**
	 * 移动分类
	 * @param {*} params BaseFromMysteelChemicalClassifyId PrevBaseFromMysteelChemicalClassifyId NextBaseFromMysteelChemicalClassifyId
	 ParentBaseFromMysteelChemicalClassifyId
	 * @returns 
	 */
	classifyMove: params => {
		return http.post('/datamanage/mysteel_chemical/classify/move',params)
	},

	/**
	 * 获取频度
	 * @param {*} params BaseFromMysteelChemicalClassifyId
	 * @returns 
	 */
	frequencyList: params => {
		return http.get('/datamanage/mysteel_chemical/frequency',params)
	},

	/**
	 * 数据接口 
	 * @param {*} params BaseFromMysteelChemicalClassifyId Frequency
	 * @returns 
	 */
	dataList: params => {
		return http.get('/datamanage/mysteel_chemical/data',params)
	},

	/**
	 * 新增指标
	 * @param {*} params BaseFromMysteelChemicalClassifyId IndexCode UpdateWeek
	 * @returns 
	 */
	edbAdd: params => {
		return http.post('/datamanage/mysteel_chemical/add',params)
	},

	/**
	 * 编辑指标
	 * @param {*} params 
	 * BaseFromMysteelChemicalIndexId
	 * BaseFromMysteelChemicalClassifyId
	 * UpdateWeek
	 * UpdateTime
	 * @returns 
	 */
	edbEdit: params => {
		return http.post('/datamanage/mysteel_chemical/edit',params)
	},

	/**
	 * 指标详情
	 * BaseFromMysteelChemicalIndexId
	 * @param {*} params 
	 * @returns 
	 */
	edbDetail: params => {
		return http.get('/datamanage/mysteel_chemical/detail',params)
	},

	/**
	 * 指标移动
	 * BaseFromMysteelChemicalIndexId 
	 * BaseFromMysteelChemicalClassifyId
	 * NextBaseFromMysteelChemicalIndexId
	 * PrevBaseFromMysteelChemicalIndexId
	 * @param {*} params 
	 * @returns 
	 */
	edbMove: params => {
		return http.post('/datamanage/mysteel_chemical/move',params)
	},

	/**
	 * 指标删除
	 * @param {*} params BaseFromMysteelChemicalIndexId
	 * @returns 
	 */
	edbDel: params => {
		return http.post('/datamanage/mysteel_chemical/del',params)
	},

	/**
	 * 搜索指标
	 * @param {*} params Keyword
	 * @returns 
	 */
	searchEdb: params => {
		return http.get('/datamanage/mysteel_chemical/search',params)
	},

	/**
	 * 指标刷新
	 * @param {*} params BaseFromMysteelChemicalIndexId
	 * @returns 
	 */
	edbRefresh: params => {
		return http.get('/datamanage/mysteel_chemical/refresh',params)
	}
}

/* ela steo */
const steoInterface = {
	/**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */
	 classifyList: params => {
		return http.get('/datamanage/eia_steo/classify',params);
	},
	/**
	 * 数据列表
	 * @param {BaseFromEiaSteoClassifyId } params 分类id
	 * @param {IndexCode } params
	 * @param {PageSize } params
	 * @param {CurrentIndex } params
	 * @param {IsExport } params
	 * @returns 
	 */
	dataList: params => {
		return http.get('/datamanage/eia_steo/data',params);
	},

	/**
	 * 指标搜索接口Keyword
	 * 
	 * */  
	targetSearch: params=>{
		return http.get('/datamanage/eia_steo/search_list',params)
	},
}

/* 卓创数据库 */
const sciDataInterface = {
  /**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */

  classifyList:params=>{
    return http.get('/datamanage/sci/classify',params)
  },

  /**
	 * 频度列表
	 * @param {ClassifyId} 分类id
	 * @returns 
	 */

  frequencyList:params=>{
    return http.get('/datamanage/sci/frequency',params)
  },

  /**
	 * 获取目录详情
	 * @param {ClassifyId}  分类id
	 * @param {Frequency}  频度名称
   * @param {CurrentIndex}
   * @param {PageSize}
	 * @returns 
	 */
  dataList:params=>{
    return http.get('/datamanage/sci/data',params);
  },

  /**
	 * 获取单个指标详情
	 * @param {IndexCode}  指标id
	 * @returns 
	 */

  getTargetDataList:params=>{
    return http.get('/datamanage/sci/single_data',params)
  },

  /**
	 * 搜索指标
	 * @param {Keyword}  搜索关键词
	 * @returns 
	 */
  getTargetListByName:params=>{
    return http.get('/datamanage/sci/search_list',params)
  },

  /**
	 * 添加分类
	 * @param {ParentId} 上级id 为0表示是一级分类
   * @param {ClassifyName} 分类名称
	 */
  addClassifyItem:params=>{
    return http.post('/datamanage/sci/classify/add',params)
  },
  /**
   * 编辑分类
   * @param {ClassifyId} 分类id
   * @param {ClassifyName} 分类名称
   */
  editClassifyItem:params=>{
    return http.post('/datamanage/sci/classify/edit',params)
  },
  /**
   * 删除分类
   * @param {ClassifyId} 分类id
   */
  deleteClassifyItem:params=>{
    return http.post('/datamanage/sci/classify/del',params)
  },
  /**
	 * 移动目录
	 * @param {ClassifyId} 分类id
   * @param {ParentId} 上级id
   * @param {PrevClassifyId} 上一个兄弟节点分类id 若移动到第一个 为0
   * @param {NextClassifyId} 下一个兄弟节点分类id 若移动到最后一个 为0
	 */
  moveCatalog:params=>{
    return http.post('/datamanage/sci/classify/move',params)
  },

  /**
   * 分类名称列表
   */
  classifyNameList:params=>{
    return http.get('/datamanage/sci/classify/name',params)
  },
  /**
	 * 编辑指标分类（移动指标）
	 * @param {ClassifyId} 分类id
   * @param {BaseFromSciIndexId} 指标id
	 */
  editSciTarget:params=>{
    return http.post('/datamanage/sci/edit',params)
  },
  /**
	 * 删除指标
   * @param {BaseFromSciIndexId} 指标id
	 */
  deleteSCItarget:params=>{
    return http.post('/datamanage/sci/del',params)
  },
  /**
	 * 清除指标分类
   * @param {BaseFromSciIndexId} 指标id
	 */
  cleanClassify:params=>{
    return http.post('/datamanage/sci/reset',params)
  },
  /**
	 * 移动指标
	 * @param {ClassifyId} 分类id
   * @param {BaseFromSciIndexId} 指标id
   * @param {PrevBaseFromSciIndexId} 上一个兄弟节点分类id 若移动到第一个 为0
   * @param {NextBaseFromSciIndexId} 下一个兄弟节点分类id 若移动到最后一个 为0
	 */
  moveSCItarget:params=>{
    return http.post('/datamanage/sci/move',params)
  },
  
}

/* 百川盈孚数据库 */
const baiinfoInterface = {
	/**
	 * 分类列表
	 * @param {} params 
	 * @returns 
	 */
	classifyList: params => {
		return http.get('/datamanage/baiinfo/classify',params);
	},
	/**
	 * 获取指标列表详情
	 * @param {ClassifyId}  分类id
	 * @param {Frequency}  频度名称
   * @param {CurrentIndex}
   * @param {PageSize}
	 * @returns 
	 */
	dataList: params => {
		return http.get('/datamanage/baiinfo/data',params);
	},
	/**
	 * 频度列表
	 * @param {ClassifyId} params 
	 */
	frequencyList: params => {
		return http.get('/datamanage/baiinfo/frequency',params);
	},

	// smm指标搜索接口
	getTargetListByName:params=>{
		return http.get('/datamanage/baiinfo/search_list',params)
	},
	/**
	 * 获取单个指标详情
	 * @param {IndexCode}  指标id
	 * @returns 
	 */
	getTargetDataList:params=>{
		return http.get('/datamanage/baiinfo/single_data',params)
	},
  /**
	 * 添加分类
	 * @param {ParentId} 上级id 为0表示是一级分类
   * @param {ClassifyName} 分类名称
	 */
  addClassifyItem:params=>{
    return http.post('/datamanage/baiinfo/classify/add',params)
  },
  /**
	 * 编辑分类
	 * @param {ClassifyId} 分类id
   * @param {ClassifyName} 分类名称
	 */
   editClassifyItem:params=>{
     return http.post('/datamanage/baiinfo/classify/edit',params)
   },
   /**
	 * 删除分类
	 * @param {ClassifyId} 分类id
	 */
  deleteClassifyItem:params=>{
    return http.post('/datamanage/baiinfo/classify/del',params)
  },
  /**
   * 分类名称列表
   */
  classifyNameList:params=>{
    return http.get('/datamanage/baiinfo/classify/name',params)
  },
  /**
	 * 编辑指标
	 * @param {ClassifyId} 分类id
   * @param {BaseFromSmmIndexId} 指标id
	 */
  editSmmTarget:params=>{
    return http.post('/datamanage/baiinfo/edit',params)
  },
  /**
	 * 移动目录
	 * @param {ClassifyId} 分类id
   * @param {ParentId} 上级id
   * @param {PrevClassifyId} 上一个兄弟节点分类id 若移动到第一个 为0
   * @param {NextClassifyId} 下一个兄弟节点分类id 若移动到最后一个 为0
	 */
  moveCatalog:params=>{
    return http.post('/datamanage/baiinfo/classify/move',params)
  },
  /**
	 * 移动指标
	 * @param {ClassifyId} 分类id
   * @param {BaseFromSmmIndexId} 指标id
   * @param {PrevBaseFromSmmIndexId} 上一个兄弟节点分类id 若移动到第一个 为0
   * @param {NextBaseFromSmmIndexId} 下一个兄弟节点分类id 若移动到最后一个 为0
	 */
  moveSMMtarget:params=>{
    return http.post('/datamanage/baiinfo/move',params)
  },
  /**
	 * 删除指标
   * @param {BaseFromSmmIndexId} 指标id
	 */
  deleteSMMtarget:params=>{
    return http.post('/datamanage/baiinfo/del',params)
  },
  /**
	 * 清除指标分类
   * @param {BaseFromSmmIndexId} 指标id
	 */
  cleanClassify:params=>{
    return http.post('/datamanage/baiinfo/reset',params)
  }
}

/* 国家统计局数据库 */

const nationalInterface = {
    /**
     * 获取菜单列表
     * @param {*} params 
     */
    getMenuList:params=>{
        return http.get('/datamanage/base_from_national_statistics/db_list',params)
    },
    /**
     * 获取对应菜单下，指标分类列表
     * @param {Object} params 
     * @param {String} params.Dbcode
     */
    getClassifyList:params=>{
        return http.get('/datamanage/base_from_national_statistics/classify_list',params)
    },
    /**
     * 获取对应指标分类/关键词下，指标列表
     * @param {Object} params 
     * @param {String} params.Dbcode
     * @param {Number} params.ClassifyId 选填
     * @param {String} params.Keywords 选填
     */
    getIndexList:params=>{
        return http.get('/datamanage/base_from_national_statistics/index_list',params)
    },
    /**
     * 获取指标详情
     * @param {Object} params 
     * @param {Number} params.IndexId
     * @param {Number} params.ClassifyId 
     * @param {String} params.Reg 地区
     * @param {Boolean} params.IsExport 是否导出 选填
     */
    getIndexDetail:params=>{
        return http.get('/datamanage/base_from_national_statistics/index_detail',params)
    }
}

export { 
	lzDataInterface,
	glDataInterface,
	smmDataInterface,
	coalDataInterface,
	steelInterface,
	steoInterface,
  sciDataInterface,
  baiinfoInterface,
  nationalInterface
}